==> jc-1.4.0.tar.gz: soot/jimple/toolkits/base/Zonation.h <==
// public class soot.jimple.toolkits.base.Zonation

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 18e4e0e5c399b935 soot_jimple_toolkits_base_Zonation

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_base_Zonation_H_
#define _JC_soot_jimple_toolkits_base_Zonation_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_StmtBody$object;
struct _jc_soot_jimple_toolkits_base_Zone$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_base_Zonation$sub_refs	_jc_soot_jimple_toolkits_base_Zonation$sub_refs;
typedef struct _jc_soot_jimple_toolkits_base_Zonation$sub_nonrefs	_jc_soot_jimple_toolkits_base_Zonation$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_base_Zonation$refs	_jc_soot_jimple_toolkits_base_Zonation$refs;
typedef struct _jc_soot_jimple_toolkits_base_Zonation$nonrefs	_jc_soot_jimple_toolkits_base_Zonation$nonrefs;
typedef struct _jc_soot_jimple_toolkits_base_Zonation$object	_jc_soot_jimple_toolkits_base_Zonation$object;

typedef const struct _jc_soot_jimple_toolkits_base_Zonation$vmethods	_jc_soot_jimple_toolkits_base_Zonation$vmethods;
typedef const struct _jc_soot_jimple_toolkits_base_Zonation$vtable	_jc_soot_jimple_toolkits_base_Zonation$vtable;
typedef const struct _jc_soot_jimple_toolkits_base_Zonation$vtype	_jc_soot_jimple_toolkits_base_Zonation$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_base_Zonation$method$_init$19e6b86ac329f83e(_jc_env *, struct _jc_soot_jimple_toolkits_base_Zonation$object *, struct _jc_soot_jimple_StmtBody$object *);

// Virtual methods
extern jint _jc_soot_jimple_toolkits_base_Zonation$method$getZoneCount$e7d0b828984710aa(_jc_env *, struct _jc_soot_jimple_toolkits_base_Zonation$object *);
extern struct _jc_soot_jimple_toolkits_base_Zone$object *_jc_soot_jimple_toolkits_base_Zonation$method$getZoneOf$e06a174aba589811(_jc_env *, struct _jc_soot_jimple_toolkits_base_Zonation$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_base_Zonation$method_info$getZoneCount$e7d0b828984710aa;
extern _jc_method _jc_soot_jimple_toolkits_base_Zonation$method_info$getZoneOf$e06a174aba589811;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_base_Zonation$vmethods {
	jint	(*getZoneCount$e7d0b828984710aa)(_jc_env *, struct _jc_soot_jimple_toolkits_base_Zonation$object *);
	struct _jc_soot_jimple_toolkits_base_Zone$object	*(*getZoneOf$e06a174aba589811)(_jc_env *, struct _jc_soot_jimple_toolkits_base_Zonation$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_base_Zonation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_base_Zonation$vmethods	soot_jimple_toolkits_base_Zonation;
};

// Vtype
struct _jc_soot_jimple_toolkits_base_Zonation$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_base_Zonation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_base_Zonation$sub_refs {
	struct _jc_object	*unitToZone;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_base_Zonation$refs {
    _jc_soot_jimple_toolkits_base_Zonation$sub_refs	soot_jimple_toolkits_base_Zonation;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_base_Zonation$sub_nonrefs {
	jint	zoneCount;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_base_Zonation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_base_Zonation$sub_nonrefs	soot_jimple_toolkits_base_Zonation;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_base_Zonation$object {
	_jc_soot_jimple_toolkits_base_Zonation$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_base_Zonation$vtype	*vtype;
	_jc_soot_jimple_toolkits_base_Zonation$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_base_Zonation$vtype _jc_soot_jimple_toolkits_base_Zonation$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_base_Zonation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_base_Zonation$class_object;

#endif	/* _JC_soot_jimple_toolkits_base_Zonation_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/base/Zonation.h <==
// public class soot.jimple.toolkits.base.Zonation

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 18e4e0e5c399b935 soot_jimple_toolkits_base_Zonation

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_base_Zonation_H_
#define _JC_soot_jimple_toolkits_base_Zonation_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_StmtBody$object;
struct _jc_soot_jimple_toolkits_base_Zone$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_base_Zonation$sub_refs	_jc_soot_jimple_toolkits_base_Zonation$sub_refs;
typedef struct _jc_soot_jimple_toolkits_base_Zonation$sub_nonrefs	_jc_soot_jimple_toolkits_base_Zonation$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_base_Zonation$refs	_jc_soot_jimple_toolkits_base_Zonation$refs;
typedef struct _jc_soot_jimple_toolkits_base_Zonation$nonrefs	_jc_soot_jimple_toolkits_base_Zonation$nonrefs;
typedef struct _jc_soot_jimple_toolkits_base_Zonation$object	_jc_soot_jimple_toolkits_base_Zonation$object;

typedef const struct _jc_soot_jimple_toolkits_base_Zonation$vmethods	_jc_soot_jimple_toolkits_base_Zonation$vmethods;
typedef const struct _jc_soot_jimple_toolkits_base_Zonation$vtable	_jc_soot_jimple_toolkits_base_Zonation$vtable;
typedef const struct _jc_soot_jimple_toolkits_base_Zonation$vtype	_jc_soot_jimple_toolkits_base_Zonation$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_base_Zonation$method$_init$19e6b86ac329f83e(_jc_env *, struct _jc_soot_jimple_toolkits_base_Zonation$object *, struct _jc_soot_jimple_StmtBody$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_jimple_toolkits_base_Zonation$method$getZoneCount$e7d0b828984710aa(_jc_env *, struct _jc_soot_jimple_toolkits_base_Zonation$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_toolkits_base_Zone$object *_jc_soot_jimple_toolkits_base_Zonation$method$getZoneOf$e06a174aba589811(_jc_env *, struct _jc_soot_jimple_toolkits_base_Zonation$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_base_Zonation$method_info$getZoneCount$e7d0b828984710aa;
extern _jc_method _jc_soot_jimple_toolkits_base_Zonation$method_info$getZoneOf$e06a174aba589811;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_base_Zonation$vmethods {
	jint	(*getZoneCount$e7d0b828984710aa)(_jc_env *, struct _jc_soot_jimple_toolkits_base_Zonation$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_toolkits_base_Zone$object	*(*getZoneOf$e06a174aba589811)(_jc_env *, struct _jc_soot_jimple_toolkits_base_Zonation$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_base_Zonation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_base_Zonation$vmethods	soot_jimple_toolkits_base_Zonation;
};

// Vtype
struct _jc_soot_jimple_toolkits_base_Zonation$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_base_Zonation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_base_Zonation$sub_refs {
	struct _jc_object	*unitToZone;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_base_Zonation$refs {
    _jc_soot_jimple_toolkits_base_Zonation$sub_refs	soot_jimple_toolkits_base_Zonation;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_base_Zonation$sub_nonrefs {
	jint	zoneCount;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_base_Zonation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_base_Zonation$sub_nonrefs	soot_jimple_toolkits_base_Zonation;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_base_Zonation$object {
	_jc_soot_jimple_toolkits_base_Zonation$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_base_Zonation$vtype	*vtype;
	_jc_soot_jimple_toolkits_base_Zonation$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_base_Zonation$vtype _jc_soot_jimple_toolkits_base_Zonation$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_base_Zonation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_base_Zonation$class_object;

#endif	/* _JC_soot_jimple_toolkits_base_Zonation_H_ */
